======================
Salt Table of Contents
======================

.. toctree::
    :maxdepth: 3
    :glob:

    faq

    topics/index
    topics/installation/index
    topics/configuration
    topics/hacking
    topics/targeting/index
    topics/tutorials/index
    topics/eauth/*
    topics/pillar/index
    topics/master_tops/index
    topics/jobs/*
    topics/nonroot
    topics/troubleshooting/*
    topics/community
    topics/projects/index
    topics/event/index
    topics/mine/*
    topics/cloud/index
    topics/virt/*
    topics/ssh/*
    topics/tests/*
    topics/reactor/*
    topics/conventions/*
    topics/git/*
    topics/development/index
    topics/translating
    topics/salt_projects
    topics/proxyminion/index

    ref/configuration/logging/*
    ref/configuration/logging/handlers/*
    ref/index
    ref/modules/*
    ref/modules/all/index
    ref/returners/*
    ref/returners/all/index
    ref/states/*
    ref/states/all/index
    ref/renderers/*
    ref/renderers/all/index
    ref/pillar/*
    ref/pillar/all/index
    ref/tops/*
    ref/tops/all/index
    ref/runners/index
    ref/runners/all/index
    ref/wheel/all/index
    ref/auth/all/index
    ref/output/all/index
    ref/clouds/all/index
    ref/clients/index
    ref/peer
    ref/clientacl
    ref/syndic
    ref/file_server/*
    ref/file_server/all/index
    ref/configuration/*
    ref/internals/index
    ref/topology
    ref/windows-package-manager

    ref/cli/index
    ref/cli/salt
    ref/cli/salt-master
    ref/cli/salt-minion
    ref/cli/salt-key
    ref/cli/salt-cp
    ref/cli/salt-call
    ref/cli/salt-run
    ref/cli/salt-ssh
    ref/cli/salt-syndic
    ref/cli/salt-cloud

    topics/releases/index
